Package: recount
Title: Explore and download data from the recount project
Version: 1.37.0
Date: 2024-05-21
Authors@R: c(person("Leonardo", "Collado-Torres", role = c("aut", "cre"),
    email = "lcolladotor@gmail.com", comment = c(ORCID = "0000-0003-2140-308X")),
    person("Abhinav", "Nellore", role = "ctb",
    email = "anellore@gmail.com"), person(c("Andrew", "E."), "Jaffe",
    role = "ctb", email = "andrew.jaffe@libd.org",
    comment = c(ORCID = "0000-0001-6886-1454")), person(c("Margaret", "A."),
    "Taub", role = "ctb", email = "mtaub@jhsph.edu"), person("Kai", "Kammers",
    role = "ctb", email = "kai.kammers@gmail.com"), person(c("Shannon", "E."),
    "Ellis", role = "ctb", email = "sellis18@jhmi.edu",
    comment = c(ORCID = "0000-0002-9231-0481")), person(c("Kasper",
    "Daniel"), "Hansen", role = c("ctb"),
    email = "kasperdanielhansen@gmail.com",
    comment = c(ORCID = "0000-0003-0086-0687")), person("Ben", "Langmead",
    role = "ctb", email = 'langmea@cs.jhu.edu',
    comment = c(ORCID = "0000-0003-2437-1976")), person(c("Jeffrey", "T."),
    "Leek", role = c("aut", "ths"), email = "jtleek@gmail.com",
    comment = c(ORCID = "0000-0002-2873-2671")))
Depends: R (>= 3.5.0), SummarizedExperiment
Imports: BiocParallel, derfinder, downloader, GEOquery, GenomeInfoDb,
        GenomicRanges, IRanges, methods, RCurl, rentrez, rtracklayer
        (>= 1.35.3), S4Vectors, stats, utils
Suggests: AnnotationDbi, BiocManager, BiocStyle (>= 2.5.19), DESeq2,
        sessioninfo, EnsDb.Hsapiens.v79, GenomicFeatures, txdbmaker,
        knitr (>= 1.6), org.Hs.eg.db, RefManageR, regionReport (>=
        1.9.4), rmarkdown (>= 0.9.5), testthat (>= 2.1.0), covr,
        pheatmap, DT, edgeR, ggplot2, RColorBrewer
VignetteBuilder: knitr
Description: Explore and download data from the recount project available at
    https://jhubiostatistics.shinyapps.io/recount/. Using the recount package you can
    download RangedSummarizedExperiment objects at the gene, exon or exon-exon junctions level,
    the raw counts, the phenotype metadata used, the urls to the sample coverage
    bigWig files or the mean coverage bigWig file for a particular study. The
    RangedSummarizedExperiment objects can be used by different packages for
    performing differential expression analysis. Using
    http://bioconductor.org/packages/derfinder you can perform
    annotation-agnostic differential expression analyses with the data from the
    recount project as described at http://www.nature.com/nbt/journal/v35/n4/full/nbt.3838.html.
License: Artistic-2.0
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
URL: https://github.com/leekgroup/recount
BugReports: https://support.bioconductor.org/t/recount/
biocViews: Coverage, DifferentialExpression, GeneExpression, RNASeq,
        Sequencing, Software, DataImport, ImmunoOncology
RoxygenNote: 7.3.1
Roxygen: list(markdown = TRUE)
git_url: https://git.bioconductor.org/packages/recount
git_branch: devel
git_last_commit: 0f75cbd
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-11-04
NeedsCompilation: no
Packaged: 2025-11-05 00:35:32 UTC; biocbuild
Author: Leonardo Collado-Torres [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2140-308X>),
  Abhinav Nellore [ctb],
  Andrew E. Jaffe [ctb] (ORCID: <https://orcid.org/0000-0001-6886-1454>),
  Margaret A. Taub [ctb],
  Kai Kammers [ctb],
  Shannon E. Ellis [ctb] (ORCID: <https://orcid.org/0000-0002-9231-0481>),
  Kasper Daniel Hansen [ctb] (ORCID:
    <https://orcid.org/0000-0003-0086-0687>),
  Ben Langmead [ctb] (ORCID: <https://orcid.org/0000-0003-2437-1976>),
  Jeffrey T. Leek [aut, ths] (ORCID:
    <https://orcid.org/0000-0002-2873-2671>)
Maintainer: Leonardo Collado-Torres <lcolladotor@gmail.com>
