# Generated by roxygen2: do not edit by hand

export(abstract_search)
export(add_metadata)
export(add_predictions)
export(all_metadata)
export(browse_study)
export(coverage_matrix)
export(download_retry)
export(download_study)
export(expressed_regions)
export(find_geo)
export(geo_characteristics)
export(geo_info)
export(getRPKM)
export(getTPM)
export(read_counts)
export(reproduce_ranges)
export(scale_counts)
export(snaptron_query)
import(BiocParallel)
import(GEOquery)
import(GenomeInfoDb)
import(GenomicRanges)
import(IRanges)
import(RCurl)
import(S4Vectors)
import(SummarizedExperiment)
import(derfinder)
import(downloader)
import(rentrez)
importFrom(RCurl,url.exists)
importFrom(methods,is)
importFrom(stats,runif)
importFrom(utils,browseURL)
importFrom(utils,read.table)
importMethodsFrom(rtracklayer,import)
importMethodsFrom(rtracklayer,import.bw)
