#' RangedSummarizedExperiment at the gene level for study SRP009615
#'
#' [RangedSummarizedExperiment-class][SummarizedExperiment::RangedSummarizedExperiment-class] at the gene
#' level for study SRP009615. Used as an example in [scale_counts].
#' Matches the version2 file
#' (details at <https://jhubiostatistics.shinyapps.io/recount/>) under the
#' documentation tab.
#'
#' @name rse_gene_SRP009615
#' @docType data
#' @format A [RangedSummarizedExperiment-class][SummarizedExperiment::RangedSummarizedExperiment-class] as
#' created by the recount project for study with SRA id (accession number)
#' SRP009615.
#'
#' @keywords datasets
#' @seealso [scale_counts], [download_study]
#' @references <https://jhubiostatistics.shinyapps.io/recount/>
NULL
