#' Exon annotation used in recount
#'
#' Exon annotation extracted from Gencode v25 (GRCh38.p7) used in recount.
#' Data extraced on October 12th, 2017.
#'
#' @name recount_exons
#' @docType data
#' @format A [GRangesList-class][GenomicRanges::GRangesList-class] with one element per
#' gene. The names match the gene Gencode v25 ids.
#'
#' @keywords datasets
#' @seealso [reproduce_ranges], [recount_genes]
#' @references <https://jhubiostatistics.shinyapps.io/recount/>
NULL
